@@ -179,6 +179,16 @@ xp_as4_compressed_mimepart = 'child::cppa:CompressedSimpleMIMEPart[@CompressionT
 def as4compressedmimepart(package):
     return return_if_present_else_none(package, xp_as4_compressed_mimepart)
 
+xp_as4_compression_feature = 'child::cppa:Compression'
+def as4_compression(channel):
+    return return_if_present_else_none(channel, xp_as4_compression_feature)
+
+xp_as4_compression_algorithm = 'child::cppa:Compression/cppa:CompressionAlgorithm/text()'
+def as4_compression_algorithm(channel):
+    return return_if_present_else_none(channel, xp_as4_compression_algorithm)
+
+
+
 xp_receptionawareness = 'child::cppa:AS4ReceptionAwareness'
 def receptionawareness(binding):
     return return_if_present_else_none(binding, xp_receptionawareness)
@@ -905,6 +915,16 @@ def process_payloadservice(cpa, pmode, leg, channel):
     so the information cannot be mapped without loss of information.
     For ebMS3/AS4 PModes, we simplify the mapping by checking for presence
     of any compressed MIME parts and, if yes, setting the payload service.
+    """
+    if as4_compression(channel) != None:
+        pmode[leg]['PayloadService'] = {
+            'CompressionType' : as4_compression_algorithm(channel)
+        }
+    else:
+        logging.info('No Compression feature used in in channel {}'.format(channel.get('id')))
+
+
+
     """
     package_id = channel.get('package')
     if package_id != None:
@@ -918,6 +938,7 @@ def process_payloadservice(cpa, pmode, leg, channel):
             else:
                 logging.info('No payloadservice in package {}'.format(package_id))
 
+    """
 
 def process_reception_awareness(cpa, pmode, leg, channel):
     receptionawareness_config = receptionawareness(channel)
