@@ -10,6 +10,7 @@ A ChannelProfileConfig class
 from lxml import etree
 from copy import deepcopy
 import logging, os
+from schema import cppa3_content_model as cppa3_content_model
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -27,14 +28,18 @@ class ChannelProfileHandler():
         self._channel_dependencies = {}
         self._channel_dependencies_send = {}
         self._channel_dependencies_receive = {}
+        self._transports = {}
         if config != None:
             self.load_profile_config(config)
 
     def load_profile_config(self, parsed_config_document):
+        self.load_channel_config(parsed_config_document)
+        self.load_transport_config(parsed_config_document)
+
+    def load_channel_config(self, parsed_config_document):
         channels = parsed_config_document.xpath('//pycppa3:ChannelProfiles/*',
                                                 namespaces=_NSMAP)
         for channel in channels:
-
             if _pycppa3('direction') in channel.attrib:
                 direction = channel.get(_pycppa3('direction'))
                 del channel.attrib[_pycppa3('direction')]
@@ -46,6 +51,13 @@ class ChannelProfileHandler():
             if not direction:
                 self._channel_profiles[channel_profile] = channel
                 channel_dependencies = self._channel_dependencies
+                # Also add as to send and receive, if no value was provided
+                # Will be overwritten if an explicit directional definition is provided
+                if channel_profile not in self._channel_profiles_send:
+                    self._channel_profiles_send[channel_profile] = channel
+                if channel_profile not in self._channel_profiles_receive:
+                    self._channel_profiles_receive[channel_profile] = channel
+
             elif direction == 'send':
                 self._channel_profiles_send[channel_profile] = channel
                 channel_dependencies = self._channel_dependencies_send
@@ -73,52 +85,80 @@ class ChannelProfileHandler():
                     if dependent_channel not in channel_dependencies[channel_profile]:
                         channel_dependencies[channel_profile].append(dependent_channel)
 
+    def load_transport_config(self, parsed_config_document):
+        transports = parsed_config_document.xpath('//pycppa3:TransportProfiles/*',
+                                                  namespaces=_NSMAP)
+        for transport in transports:
+            transporttype = transport.tag
+            self._transports[transporttype] = transport
+
+
+
     def apply_profile_configs(self, indoc):
         outdoc = etree.Element(indoc.tag, nsmap = {
             'cppa':'http://docs.oasis-open.org/ebcore/ns/cppa/v3.0' })
         included_dependent_channels = []
-        logging.debug('@@@@@@@@@@@ processing {}'.format(indoc.tag))
+        logging.debug('Processing {}'.format(indoc.tag))
         for child in deepcopy(indoc):
-            applicable_channel_profiles = self._channel_profiles
-            applicable_channel_dependencies = self._channel_dependencies
-            if 'id' in child.attrib:
-                element_id = child.get('id')
-                if indoc.xpath(
-                    'descendant::cppa:ActionBinding[@sendOrReceive="send"]/cppa:ChannelId="{}"'.format(element_id),
-                    namespaces = _NSMAP
-                ):
-                    applicable_channel_profiles = self._channel_profiles_send
-                    applicable_channel_dependencies = self._channel_dependencies_send
-                    logging.info('@@ Channel {} is a SEND channel'.format(element_id))
-                elif indoc.xpath(
-                    'descendant::cppa:ActionBinding[@sendOrReceive="receive"]/cppa:ChannelId="{}"'.format(element_id),
-                    namespaces = _NSMAP
-                ):
-                    applicable_channel_profiles = self._channel_profiles_receive
-                    applicable_channel_dependencies = self._channel_dependencies_receive
-                    logging.info('@@ Channel {} is a RECEIVE channel'.format(element_id))
-                else:
-                    logging.info('@@ Channel {} is neither a SEND nor a RECEIVE channel'.format(element_id))
-
-            if len(child.xpath('cppa:ChannelProfile',
-                               namespaces = _NSMAP)) > 0:
-                channel_profile = child.xpath('child::cppa:ChannelProfile/text()',
-                                                namespaces = _NSMAP)[0]
-                if channel_profile in applicable_channel_profiles:
-                    default = applicable_channel_profiles[channel_profile]
-                    if child.tag != default.tag:
-                        raise Exception('{} != {}'.format(child.tag, default.tag))
-                    logging.info('Document used a channel profile {}'.format(channel_profile))
+            childtype = child.tag
+            if childtype in [ cppa('ebMS3Channel'),
+                              cppa('ebMS2Channel'),
+                              cppa('AS1Channel'),
+                              cppa('AS2Channel'),
+                              cppa('AS3Channel'),
+                              cppa('WSChannel')
+            ]:
+                applicable_channel_profiles = self._channel_profiles
+                applicable_channel_dependencies = self._channel_dependencies
+                if 'id' in child.attrib:
+                    element_id = child.get('id')
+                    if indoc.xpath(
+                        'descendant::cppa:ActionBinding[@sendOrReceive="send"]/cppa:ChannelId="{}"'.format(element_id),
+                        namespaces = _NSMAP
+                    ):
+                        applicable_channel_profiles = self._channel_profiles_send
+                        applicable_channel_dependencies = self._channel_dependencies_send
+                        logging.info('Channel {} is a SEND channel'.format(element_id))
+                    elif indoc.xpath(
+                        'descendant::cppa:ActionBinding[@sendOrReceive="receive"]/cppa:ChannelId="{}"'.format(element_id),
+                        namespaces = _NSMAP
+                    ):
+                        applicable_channel_profiles = self._channel_profiles_receive
+                        applicable_channel_dependencies = self._channel_dependencies_receive
+                        logging.info('Channel {} is a RECEIVE channel'.format(element_id))
+                    else:
+                        applicable_channel_profiles = self._channel_profiles
+                        applicable_channel_dependencies = self._channel_dependencies
+                        logging.info('Channel {} is neither a SEND nor a RECEIVE channel'.format(element_id))
+                if len(child.xpath('cppa:ChannelProfile',
+                                   namespaces = _NSMAP)) > 0:
+                    channel_profile = child.xpath('child::cppa:ChannelProfile/text()',
+                                                    namespaces = _NSMAP)[0]
+                    if channel_profile in applicable_channel_profiles:
+                        default = applicable_channel_profiles[channel_profile]
+                        if child.tag != default.tag:
+                            raise Exception('{} != {}'.format(child.tag, default.tag))
+                        logging.info('Document used a channel profile {}'.format(channel_profile))
+                        child = apply_default_to_complex_subelement(child,
+                                                                    default)
+                    if channel_profile in applicable_channel_dependencies:
+                        for dependent_channel in applicable_channel_dependencies[channel_profile]:
+                            if dependent_channel not in included_dependent_channels:
+                                logging.info('Adding dependent channel {}'.format(dependent_channel))
+                                outdoc.append(deepcopy(self._channels[dependent_channel]))
+                                included_dependent_channels.append(dependent_channel)
+            elif childtype in [
+                cppa('HTTPTransport')
+            ]:
+                logging.info('@@ Processing HTTPTransport for {}'.format(str(child)))
+                if childtype in self._transports:
+                    default = self._transports[childtype]
                     child = apply_default_to_complex_subelement(child,
                                                                 default)
-                for dependent_channel in applicable_channel_dependencies[channel_profile]:
-                    if dependent_channel not in included_dependent_channels:
-                        logging.info('Adding dependent channel {}'.format(dependent_channel))
-                        outdoc.append(deepcopy(self._channels[dependent_channel]))
-                        included_dependent_channels.append(dependent_channel)
+                logging.info('@@ Processed HTTPTransport for {}'.format(str(child)))
             outdoc.append(child)
         import lxml.etree
-        logging.debug('RESULT @@@: {}'.format(lxml.etree.tostring(outdoc,
+        logging.debug('RESULT: {}'.format(lxml.etree.tostring(outdoc,
                                                                   pretty_print=True)))
         return outdoc
 
@@ -128,73 +168,6 @@ def cppa(el):
 def pycppa3(el):
     return '{{{}}}{}'.format(_NSMAP['pycppa3'], el)
 
-
-cppa3_content_model = {
-    cppa('ebMS3Channel') : [cppa('Description'),
-                            cppa('ChannelProfile'),
-                            cppa('SOAPVersion'),
-                            cppa('FaultHandling'),
-                            cppa('Addressing'),
-                            cppa('WSSecurityBinding'),
-                            cppa('AS4ReceptionAwareness'),
-                            cppa('ErrorHandling'),
-                            cppa('ReceiptHandling'),
-                            cppa('PullHandling'),
-                            cppa('Compression'),
-                            cppa('Bundling'),
-                            cppa('Splitting'),
-                            cppa('AlternateChannel')],
-
-    cppa('WSSecurityBinding') : [ cppa('WSSVersion'),
-                                  cppa('SecurityPolicy'),
-                                  cppa('Signature'),
-                                  cppa('Encryption'),
-                                  cppa('UserAuthentication')],
-
-    cppa('AS4ReceptionAwareness') : [ cppa('DuplicateHandling'),
-                                      cppa('RetryHandling') ],
-
-
-    cppa('DuplicateHandling') : [ cppa('DuplicateElimination'),
-                                  cppa('PersistDuration') ],
-
-    cppa('RetryHandling') : [ cppa('Retries'),
-                              cppa('ExpontentialBackoff'),
-                              cppa('RetryInterval')],
-
-    cppa('Signature') : [ cppa('SignatureAlgorithm'),
-                          cppa('DigestAlgorithm'),
-                          cppa('CanonicalizationMethod'),
-                          cppa('SignatureTransform'),
-                          cppa('SigningCertificateRef'),
-                          cppa('SigningCertificateRefType'),
-                          cppa('SigningTrustAnchorRef'),
-                          cppa('SignElements'),
-                          cppa('SignAttachments'),
-                          cppa('SignExternalPayloads')],
-
-    cppa('Encryption') : [ cppa('KeyEncryption'),
-                           cppa('DataEncryption'),
-                           cppa('EncryptionCertificateRef'),
-                           cppa('EncryptionCertificateRefType'),
-                           cppa('EncryptionTrustAnchorRef')],
-
-    cppa('DataEncryption') : [ cppa('EncryptionAlgorithm'),
-                               cppa('EncryptElements'),
-                               cppa('EncryptAttachments'),
-                               cppa('EncryptExternalPayloads')],
-
-    cppa('ErrorHandling') : [ cppa('DeliveryFailuresNotifyProducer'),
-                              cppa('ProcessErrorNotifyConsumer'),
-                              cppa('ProcessErrorNotifyProducer'),
-                              cppa('SenderErrorsReportChannelId'),
-                              cppa('ReceiverErrorsReportChannelId')],
-
-    cppa('ReceiptHandling') : [ cppa('ReceiptFormat'),
-                                cppa('ReceiptChannelId')]
-
-}
-
 def apply_default_to_complex_subelement(element, default):
     default = deepcopy(default)
     tag = element.tag
@@ -307,7 +280,7 @@ def apply_default_to_complex_subelement(element, default):
 
                 previous_element = element_node.tag
 
-
+        logging.debug('Returning result from processing {}'.format(tag))
         return result
 
 
