@@ -12,6 +12,20 @@ def cppa(el):
     return '{{{}}}{}'.format(_NSMAP['cppa'], el)
 
 cppa3_content_model = {
+    cppa('ebMS2Channel') : [cppa('Description'),
+                            cppa('ChannelProfile'),
+                            cppa('MaxSize'),
+                            cppa('ErrorHandling'),
+                            cppa('ReceiptHandling'),
+                            cppa('ebMS2ReliableMessaging'),
+                            cppa('ebMS2SecurityBinding') ],
+
+    cppa('ebMS2SecurityBinding') : [cppa('Signature'),
+                                    cppa('Encryption')],
+
+    cppa('ebMS2ReliableMessaging') : [ cppa('DuplicateHandling'),
+                                       cppa('RetryHandling') ],
+
     cppa('ebMS3Channel') : [cppa('Description'),
                             cppa('ChannelProfile'),
                             cppa('SOAPVersion'),
