@@ -50,7 +50,8 @@ class CPPA3TestCase( unittest.TestCase ):
                        requested_expiration_date=None,
                        acpp_url=None,
                        bcpp_url=None,
-                       handle_defaults=False):
+                       handle_defaults=False,
+                       remove_unused_certs=True):
         logging.info('------------------------------------------')
         logging.info('Running test {}'.format(id))
         #logging.basicConfig(level=logging.DEBUG,
@@ -83,7 +84,8 @@ class CPPA3TestCase( unittest.TestCase ):
                     bcpp_url=bcpp_url,
                     default_handler = self.channel_profile_handler,
                     handle_defaults=handle_defaults,
-                    delegation_handler=is_connected_to
+                    delegation_handler=is_connected_to,
+                    remove_unused_certs=remove_unused_certs
         )
         if self.schema is not None:
             # Change the serial number as many CAs generate values that are
@@ -1299,6 +1301,12 @@ class CPPA3TestCase( unittest.TestCase ):
     # CEM.  Could be done by defining a CEM service and
     # related actions, as done for ebCore Agreement Update.
 
+    # AS2 example using a registration service.
+    # Used in internal discussion paper
+    def test_3400(self):
+        self.do_unification('3400')
+
+
     """
     ebMS2 tests
     """
@@ -1342,6 +1350,20 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_4031(self):
         self.do_unification('4031')
 
+
+    # SMTP transport,  signing,  signed asynchronous receipts and errors,
+    # Two versions of a service,  distinguished by payload profile.
+    # B also supports AS4.
+
+    def test_4100(self):
+        self.do_unification('4100')
+
+    # Here A also supports AS4
+    def test_4101(self):
+        self.do_unification('4101', remove_unused_certs=True)
+
+
+
     # Synchronous Business Response
 
     # Two Way MEP,  asynchronous
@@ -1386,6 +1408,14 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_5005(self):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '5005')
 
+    # Version of test 3400 using a delegation channel
+    def test_5100(self):
+        self.do_unification('5100')
+
+
+    """
+    ebCore Connect
+    """
 
 
     """
